<?
    /*
     * File: project.php
     *
     * Description:
     *     Utility functions that can be used on projects.
     *
     * Creator: Chris Ryan <chris@greatbridge.com>
     * Created: 09/26/2000
     *
     * Change Log:
     *     Chris Ryan <chris@greatbridge.com> 09/26/2000
     *         - Initial File creation
     *     Chris Ryan <chris@greatbridge.com> 10/02/2000
     *         - Added findTask() and findTaskInProject() functions
     *         - Added getTaskStatusList() function
     *     Allen McGrath <amcgrath@greatbridge.com> 10/11/2000
     *         - Added the category build function getCats.
     *     Allen McGrath <amcgrath@greatbridge.com> 10/16/2000
     *         - Added the news build function getNews.
     *     Chris Ryan <chris@greatbridge.com> 10/24/2000
     *         - Added some comments to functions
     *         - Added the use of pg_freeresult after completing queries
     *         - did some general formatting of code
     *     Chris Ryan <chris@greatbridge.com> 10/25/2000
     *         - changed getTaskStatusList() to not included the undefined
     *           option in the list
     *         - added the description to the task list functions
     *         - changed query of getTaskStatusList to sort result by cat_id
     *     Chris Ryan <chris@greatbridge.com> 11/06/2000
     *         - Added an order by clause on the query in getCats()
     *     Chris Ryan <chris@greatbridge.com> 11/07/2000
     *         - changed the order by clause on getNews to be descending
     *     Chris Ryan <chris@greatbridge.com> 11/14/2000
     *         - added the function getErrataCategories()
     *         - added getProjectVersions() function
     *         - added getErrataList() function
     *     Chris Ryan <chris@greatbridge.com> 12/28/2000
     *         - added additional (optional) paremeter to getNews
     *           to specify to get only active news items (true) or
     *           all news items (false)
     *         - added getProjectCountInCategory() function
     *     Chris Ryan <chris@greatbridge.com> 01/02/2001
     *         - Changed getNews() to only get items where active = true
     *           and to check the option passed to new on_homepage field
     *         - added code to the getProjectCountInCategory() function
     *           select to ignore unapproved projects
     */

    /*
     * Function: findProject
     *
     * Desctription:
     *     Finds a project using the id passed in. First it will find a
     * project where project_id matches the id passed in. If it can't find
     * a match then it will try and find a project by the project_name matching
     * the id passed in. If it still can't find a project it will return 0.
     */
    function findProject($project_id,$site_group_id) {
        global $conn;

        $field_list = "project_id";
        if(is_numeric($project_id)) {
            $query = "select $field_list ".
                     "  from project ". 
                     " where project_id = $project_id ".
                     "   and (site_group_id = 0 ".
                 (!empty($site_group_id)?
                     "   or site_group_id = $site_group_id":"") . ") ".
                     "   and approved = true ";
            $res   = pg_exec($conn,$query);
        }
        
        if(empty($res) || pg_numrows($res) == 0) {
            $query = "select $field_list ".
                     "  from project ".
                     " where project_name = '$project_id' ".
                     "   and (site_group_id = 0 ".
                 (!empty($site_group_id)?
                     "   or site_group_id = $site_group_id":"") . ") ".
                     "   and approved = true ";
            $res   = pg_exec($conn,$query);
        }

        if(!empty($res) && pg_numrows($res) > 0) {
            $ret = @pg_result($res,0,0);
            pg_freeresult($res);
        } else {
            $ret = 0;
        }

        return $ret;
    }

    /*
     * Function: getProjectName($project_id)
     *
     * Description: Gets the name of the project specified.
     */
    function getProjectName($project_id) {
        global $conn;
        $query = "select project_name ".
                 "  from project ".
                 " where project_id = $project_id";
        $res   = @pg_exec($conn,$query);
        if(!empty($res) && pg_numrows($res) > 0) {
            $ret = pg_result($res,0,0);
            pg_freeresult($res);
            return $ret;
        }
        return "";
    }

    /*
     * Function: findTask($task_id)
     *
     * Description: find a task on the database.
     */
    function findTask($task_id) {
        global $conn;

        if(!empty($task_id)) {
            $query = "select task_id from task where task_id = $task_id";
            $res   = @pg_exec($conn,$query);
            if(!empty($res) && pg_numrows($res) > 0) {
                $ret = pg_result($res,0,0);
                pg_freeresult($res);
                return $ret;
            }
        }

        return "";
    }

    /*
     * Function: findTaskInProject($task_id,$project_id)
     *
     * Description: find a task on the database.
     */
    function findTaskInProject($task_id,$project_id) {
        global $conn;

        if(!empty($task_id)) {
            $query = "select task_id ".
                     "  from task ".
                     " where task_id = $task_id" .
                     "   and project_id = $project_id ";
            $res   = @pg_exec($conn,$query);
            if(!empty($res) && pg_numrows($res) > 0) {
                $ret = pg_result($res,0,0);
                pg_freeresult($res);
                return $ret;
            }
        }

        return "";
    }

    /*
     * Function: getTaskStatusList()
     *
     * Description: returns an array of id = value of Task statuses
     */
    function getTaskStatusList() {
        global $conn;
        $query = "  select cat_id, cat_name, cat_description ".
                 "    from category ".
                 "   where type_id = 3 ".
                 "order by cat_id ";
        $res   = pg_exec($conn,$query);
        $r = 0;
        while($row = @pg_fetch_array($res,$r++)) {
            $status_list[$row["cat_id"]] =
                array("name" => $row["cat_name"],
                      "desc" => $row["cat_description"]);
        }
        pg_freeresult($res);
        return $status_list;
    }

    /*
     * Function: getProjectMembers($project_id)
     *
     * Description: Returns an array of member_id = member_name with
     *              all the members who are part of the specified project.
     */
    function getProjectMembers($project_id) {
        global $conn;
        $query = "  select member.member_id as member_id, ".
                 "         member.member_name as member_name ".
                 "    from member, member_role ".
                 "   where member.member_id = member_role.member_id ".
                 "     and member_role.project_id = $project_id ".
                 "order by member_name ";
        $res   = pg_exec($conn,$query);
        $r = 0;
        while($row = @pg_fetch_array($res,$r++)) {
            $project_members[$row["member_id"]] = $row["member_name"];
        }
        pg_freeresult($res);
        return $project_members;
    }
		

    /*
     * Function: getCats($cat_id)
     *
     * Description: Builds a tree of values for project categories
     */
    function getCats($cat_id) {
        global $HTTP_HOST;
        global $conn;
        $query = "  select cat_id, cat_name " .
	         "    from category " .
                 "   where type_id = 7 ".
                 "     and parent_id = $cat_id ".
                 "order by cat_id ";
        $res   = pg_exec($conn,$query);
        $r = 0;
        while($row = @pg_fetch_array($res,$r++)) {
            unset($children);
            $children = getCats($row["cat_id"]);
            $cat_list[] = array( "cat_id" => $row["cat_id"],
                                 "cat_name" => $row["cat_name"],
                                 "children"  => $children );
        }
        pg_freeresult($res);
        return $cat_list;
    }		

    /*
     * Function: getProjectCountInCategory($cat_id,$count_subs=false)
     *
     * Description: gets the number of projects in a category
     *              and the categories children if $count_subs == true.
     */
    function getProjectCountInCategory($cat_id,$count_subs = false) {
        global $conn;

        $query = "select count(*) ".
                 "  from project_category a, project b ".
                 " where a.project_id = b.project_id ".
                 "   and b.approved = 't' ".
                 "   and a.cat_id = $cat_id";
        $res   = @pg_exec($conn,$query);
        if(empty($res)) {
            $count = 0;
        } else {
            $count = pg_result($res,0,0);
            pg_freeresult($res);
        }
        if($count_subs == true) {
            $query = "select cat_id ".
                     "  from category ".
                     " where type_id = 7 and parent_id = $cat_id";
            $res   = @pg_exec($conn,$query);
            if(!empty($res) && pg_numrows($res) > 0) {
                $r = 0;
                while($sub_id = @pg_result($res,$r++,0)) {
                    $count += getProjectCountInCategory($sub_id,$count_subs);
                }
                pg_freeresult($res);
            }
        }
        return $count;
    }


    /*
     * Function: getNews($site_group_id, $project_id, $news_id, $active = true)
     *
     * Description: Find one or more news items based on the
     *              parameters passed into the function. The
     *              information is passed back as an associative
     *              array.
     */
    function getNews($site_group_id,$project_id,$news_id, $active = true) {
        global $conn;
        if ($project_id > 0) 
            $projins = " AND C.PROJECT_ID = " . $project_id ;
	if ($news_id > 0)
            $projins .= " AND A.NEWS_ID = " . $news_id ;
		
        $news_query = "SELECT A.NEWS_ID, A.PROJECT_ID, A.HEADLINE, ".
                      "       A.BODY, A.SUBMIT_DATE, " .
                      "       B.MEMBER_NAME, B.EMAIL, B.MEMBER_ID, " .
                      "       C.PROJECT_NAME " .
                      "  FROM PROJECT_NEWS A, MEMBER B, PROJECT C " .
                      " WHERE GROUP_ID = $site_group_id " .
                      "   AND A.ACTIVE = 't' " .
                      ($active == true?"   AND A.ON_HOMEPAGE = 't' ":"") .
                      "   AND A.MEMBER_ID = B.MEMBER_ID " .
                      $projins .
                      "   AND A.PROJECT_ID = C.PROJECT_ID " .
                      " ORDER BY SUBMIT_DATE DESC";
        $news_result = pg_exec($conn,$news_query);
        $ns = 0;
        while ($row = @pg_fetch_array($news_result,$ns++)) {
            $news_list[] = array( "news_id"      => $row["news_id"],
                                  "headline"     => $row["headline"],
                                  "email"        => $row["email"],
                                  "submit_date"  => $row["submit_date"],
                                  "body"         => $row["body"],
                                  "project_name" => $row["project_name"],
                                  "member_name"  => $row["member_name"],
                                  "member_id"    => $row["member_id"]);
        }
        pg_freeresult($news_result);
        return $news_list;
    }			

    /*
     * Function: getProjectVersions($project_id)
     *
     * Description: list the versions of a project by version_id, version_code
     *              in an associative array and return that array
     */
    function getProjectVersions($project_id) {
        global $conn;

        $query = "  select version_id, version_code ".
                 "    from project_version ".
                 "   where project_id = $project_id ".
                 "order by version_id desc ";
        $res   = pg_exec($conn,$query);
        $r = 0;
        while($row = @pg_fetch_array($res,$r++)) {
            $versionList[$row["version_id"]] = $row["version_code"];
        }
        return $versionList;
    }

    /*
     * Function: getErrataCategories()
     *
     * Description: list the errata categories in an associative array and
     *              return that array back to the caller
     */
    function getErrataCategories() {
        global $conn;
        global $ERRATA_TYPE_ID;
        $query = "  select cat_id, cat_name ".
                 "    from category ".
                 "   where type_id = $ERRATA_TYPE_ID ".
                 "order by cat_id ";
        $res   = pg_exec($conn,$query);
        $r = 0;
        while($row = @pg_fetch_array($res,$r++)) {
            $errataCats[$row["cat_id"]] = $row["cat_name"];
        }
        return $errataCats;
    }

    /*
     * Function: getErrataList($project_id)
     *
     * Description: Returns an array of all the errata entries for a project
     *              sorted primary by version_id descending order then sub
     *              sorted by cat_id acending.
     */
    function getErrataList($project_id) {
        global $conn;

        $query = "  select errata_id, project_errata.version_id as version_id, ".
                 "         title,project_errata.description, cat_id ".
                 "    from project_errata, project_version ".
                 "   where project_version.project_id = $project_id ".
                 "     and project_errata.version_id = project_version.version_id ".
                 "order by project_version.version_id desc, ".
                 "         project_errata.cat_id ";
        $res   = pg_exec($conn,$query);
        $r = 0;
        while($row = @pg_fetch_array($res,$r++)) {
            $errataList[] = $row;
        }
        return $errataList;
    }

    /*
     * Function: mailTask($task_id, $send_to, $header_tag, $comments)
     *
     * Description: Sends and email to the address specified in $send_to
     *              with the any additional header_Tag and comments attached.
     */
    function mailTask($task_id, $send_to, $header_tag, $comments) {
        global $conn;

        $query = "select task_id, task_name, assigned_to, ".
                 "       start_date, end_date, hours, percent_done, ".
                 "       c1.cat_name as status_id, priority, comments ".
                 "  from task, category c1 ".
                 " where task_id = $task_id ".
                 "   and c1.cat_id = task.status_id ";
        $res   = @pg_exec($conn,$query);
        $task = @pg_fetch_array($res,0);
        mail($send_to,"TASK: ${task["task_name"]} (ID: $task_id) $header_tag",
             "$comments

Title: ${task["task_name"]}
Assigned To: ". getMemberName($task["assigned_to"]) . "
Start date: ${task["start_date"]}
End date: ${task["end_date"]}
Estimated Hours to Complete: ${task["hours"]}
Percent Complete: ${task["percent_done"]}%
Status: ${task["status_id"]}
Priority: ${task["priority"]}
Description: ${task["comments"]}
","From: webmaster@greatbridge.org");
    }
 ?>
