<?
    /*
     * File: user.php
     *
     * Description:
     * This file contains library functions that work with users.
     *
     * Creator: Chris Ryan <chris@greatbridge.com>
     * Created: 09/18/2000
     *
     * Change Log:
     *     Chris Ryan <chris@greatbridge.com> 09/18/2000
     *         - Initial File Creation
     *     Chris Ryan <chris@greatbridge.com> 09/19/2000
     *         - Added code to update last_updated field on member_session
     *           table to keep session active
     *     Chris Ryan <chris@greatbridge.com> 09/26/2000
     *         - Added getUserAccess() function
     *     Chris Ryan <chris@greatbridge.com> 09/28/2000
     *         - Added the getMemberName() function
     *     Chris Ryan <chris@greatbridge.com> 10/17/2000
     *         - Added function getMemberRoles()
     *     Chris Ryan <chris@greatbridge.com> 10/24/2000
     *         - Added the use of pg_freeresult after finishing queries
     *         - Added some additional comments
     *         - Added in a pg_exex in the getMemeberBySession function
     *           cause it was defining a query to execute but not executing
     *     Chris Ryan <chris@greatbridge.com> 02/05/2001
     *         - Added the function getMemberEmail.
     */
    require_once("config.php");
    require_once("database.php");

    /*
     * Function: getMemberBySession()
     *
     * Description:
     *     Gets the member_id from the session_id passed in. If none is
     * found then 0 is returned.
     */
    function getMemberBySession($session_id) {
        global $conn;

        $query = " select member_id ".
                 "   from member_session ".
                 "  where session_id = '$session_id' ";

        $res   = pg_exec($conn, $query);
        if(pg_numrows($res) >= 1) {
            $member_id = pg_result($res, 0, "member_id");
            pg_freeresult($res);
            # update the session record to to now() to show that
            # the session is still active
            $query = "update member_session ".
                     "   set last_updated = now() ".
                     " where session_id = '$session_id' ";
            $res   = pg_exec($conn,$query);
            pg_freeresult($res);
            return $member_id;
        } else {
            pg_freeresult($res);
            return ""; /* no user logged in */
        }
    }

    /*
     * Function: logoutMember()
     *
     * Description:
     *     Sets the cookie session_id to blank effectively loggin
     * the user out.
     */
    function LogoutMember() {
        setcookie("session_id","",0,"/");
    }

    /*
     * Function: getUserAccess()
     *
     * Description:
     *     Finds a user role_id for the project specified. If none is found
     * 0 is returned.
     */
    function getUserAccess($member_id, $project_id) {
        global $conn;
        $query = "select role_id ".
                 "  from member_role ".
                 " where member_id = $member_id ".
                 "   and project_id = $project_id ";
        $res   = @pg_exec($conn,$query);
        if(empty($res) || pg_numrows($res) == 0) {
            return 0;
        }
        $ret = pg_result($res,0,0);
        pg_freeresult($res);

        return $ret;
    }

    /*
     * Function: getMemeberName($member_id)
     *
     * Description:
     *     returns a member_name based on $member_id passed in.
     * If one couldn't be found it returns and emtpy variable.
     */
    function getMemberName($member_id) {
        global $conn;
        if(!empty($member_id)) {
            $query = "select member_name ".
                     "  from member ".
                     " where member_id = $member_id ";
            $res   = pg_exec($conn,$query);
            if(!empty($res) && pg_numrows($res) > 0) {
                $ret = pg_result($res,0,0);
                pg_freeresult($res);
                return $ret;
            }
        }
        return "";
    }

    /*
     * Function: getMemberEmail($member_id)
     *
     * Description: get the email address of the member_id specified.
     */
    function getMemberEmail($member_id) {
        global $conn;
        if(!empty($member_id)) {
            $query = "select email ".
                     "  from member ".
                     " where member_id = $member_id ";
            $res   = pg_exec($conn,$query);
            if(!empty($res) && pg_numrows($res) > 0) {
                $ret = pg_result($res,0,0);
                pg_freeresult($res);
                return $ret;
            }
        }
        return "";
    }

    /*
     * Function: getMemberRoles()
     *
     * Description: return a list of roles
     */
    function getMemberRoles() {
        global $conn;
        $query = "  select role_id,role_name ".
                 "    from role ".
                 "order by role_id ";
        $res   = pg_exec($conn,$query);
        $r = 0;
        while($row = @pg_fetch_array($res,$r++)) {
            $roles[$row["role_id"]] = $row["role_name"];
        }
        pg_freeresult($res);
        return $roles;
    }
 ?>
