<?
    /*
     * File: util.php
     *
     * Description:
     * Contains basic utility functions use throughout the site.
     *
     * Creator: Chris Ryan <chris@greatbridge.com>
     * Created: 09/20/2000
     *
     * Change Log:
     *     Chris Ryan <chris@greatbridge.com> 09/20/2000
     *         - Initial file creation
     *     Chris Ryan <chris@greatbridge.com> 09/28/2000
     *         - Added sqlText() function
     *     Chris Ryan <chris@greatbridge.com> 10/17/2000
     *         - Added fixQuotes() function
     *         - Changed sqlText to call fixQuotes()
     *         - Added sqlDate() function
     *     Chris Ryan <chris@greatbridge.com> 10/24/2000
     *         - Added the use of pg_freeresult after completed queries
     *     Chris Ryan <chris@greatbridge.com> 10/25/2000
     *         - Modified the sqlDate function to do alot more error checking
     *           of the date values
     *     Chris Ryan <chris@greatbridge.com> 11/20/2000
     *         - added function getStates()
     *         - added function getCountries()
     *     Chris Ryan <chris@greatbridge.com> 01/25/2001
     *         - added function getMailConfig()
     */


    /*
     * Function: RedirectTo($url)
     *
     * Description: Sends a redirection url and page
     */
    function RedirectTo($url) {
        header("Refresh:0;URL=$url");
        echo " ";
    }

    /*
     * Function: fixQuotes($text)
     *
     * Description: This function takes in a string and replaceses all
     * \' and \" with ' and " respectively and returns the new string.
     */
    function fixQuotes($text) {
        $text = str_replace("\\'","'",$text);
        $text = str_replace("\\\"","\"",$text);
        return $text;
    }

    /*
     * Function: sqlText($text)
     *
     * Description:
     *     Converts a string into an acceptable sql string. blank values are
     * returned as null otherwise they are quoted using single quotes (') and
     * all single quotes within the text are escaped out.
     */
    function sqlText($text) {
        if($text) {
            return "'" . str_replace("'","''",fixQuotes($text)) . "'";
        } else {
            return "null";
        }
    }

    /*
     * Function: sqlDate($date, $default = "")
     *
     * Description:
     *     Convert a string into an exceptable sql date value.
     * if default is empty then this function will return null,
     * otherwise it will return the default value, unless default
     * is equal to "now" then it will return the current value of
     * now on the database.
     */
    function sqlDate($date, $default = "") {
        global $conn;
        if(empty($date)) {
            if(empty($default)) {
                return "null";
            } else if($default == "now") {
                $query = "select now()";
                $res   = pg_exec($conn,$query);
                $ret = "'" . pg_result($res,0,0) . "'";
                pg_freeresult($res);
                return $ret;
            } else {
                return sqlDate($default);
            }
        } else {
            # should do something better than just quote the value
            # passed in but not sure what is better?!?
            $parts = split('[/.-]',$date);
            if(count($parts) < 3) {
                $dt = getdate();
                if(substr($date,-1) == "'")
                    $date = substr($date,0,-1) . "/" . $dt["year"] . "'";
                else
                    $date .= "/" . $dt["year"];
            }
            return (substr($date,0,1)!="'"?"'":"") . $date . (substr($date,-1)!="'"?"'":"");
        }
    }

    /*
     * Function: getStates()
     *
     * Description: Returns an associative array of states with state_code as
     *              the key and the value is an asscociative array with the
     *              the keys of name and country; where name is the full name
     *              of the state and country is the country code that the state
     *              is located in.
     */
    function getStates() {
        global $conn;

        $query = "  select state_code, state_name, country_code ".
                 "    from state ".
                 "order by state_name ";
        $res   = pg_exec($conn,$query);

        $r = 0;
        while($row = @pg_fetch_array($res,$r++)) {
            $stateList[$row["state_code"]] = array("name" => $row["state_name"],
                                                   "country" => $row["country_code"]);
        }

        return $stateList;
    }

    /*
     * Function: getCountries()
     *
     * Description: Returns an associative array with the country code as the
     *              key and the country name as the value
     */
    function getCountries() {
        global $conn;

        $query = "  select country_code, country_name ".
                 "    from country ".
                 "order by country_name ";

        $res   = pg_exec($conn,$query);
        $r = 0;
        while($row = @pg_fetch_array($res,$r++)) {
            $countryList[$row["country_code"]] = $row["country_name"];
        }

        return $countryList;
    }

    /*
     * Function: getMailConfig($area,$conditions);
     *
     * Description: returns and array of email addresses bases on the
     *              area and the additional query options specified.
     *
     *    example: $emails = getMailConfig("bugs","condition = 'project 3 new'
     *                         or condition = 'any'");
     */
    function getMailConfig($area,$conditions) {
        global $conn;

        $area = sqlText($area);

        $query = "select email from mail_config, member ".
                 " where mail_config.member_id = member.member_id ".
                 "   and area = $area ".
                 "   and ($conditions) ".
                 "union select send_to as email ".
                 "  from mail_config ".
                 " where member_id is null ".
                 "   and area = $area ".
                 "   and ($conditions) ";
        $res   = @pg_exec($conn,$query);
        if(!empty($res) && pg_numrows($res) > 0) {
            $r = 0;
            while($emails[] = @pg_result($res,$r++,0)) {};
        }
        return $emails;
    }
 ?>
