/*
 * File: dwnldmng.sql
 *
 * Description:
 *     The tables used for the download manager
 *
 * Creator: Chris Ryan <chris@greatbridge.com>
 * Created: 10/02/2000
 *
 * Change Log:
 *     Chris Ryan <chris@greatbridge.com> 10/02/2000
 *         - Initial File creation
 */


/*
 * Table: download
 *
 * Description:
 *     Contains information about files that can be downloaded.
 *
 * Field Description:
 * download_id     the id of this download record
 * project_id      the id of the project that this download belongs to
 * branch          the branch identifier of this download
 * release         the release identifier of this download
 * comments        comments about this download
 * member_id       the id of the member who created this download
 * date_created    the date/time this download was created
 */
CREATE SEQUENCE download_download_id_seq;
CREATE TABLE download (
    download_id    int4 not null unique default nextval('download_download_id_seq'),
    project_id     int4 not null references project (project_id),
    branch         varchar(32) not null,
    release        varchar(128) not null,
    comments       text,
    member_id      int4 not null references member (member_id),
    date_created   timestamp not null default now(),
    primary key(download_id)
);

