/*
 * File: faq.sql
 *
 * Description:
 * This file contains all the faq tables
 *
 * Creator: Allen McGrath<amcgrath@greatbridge.com>
 * Created: 01/15/2000
 *
 * Change log:
 * 01/15/2000 -- initial creation 

*/

-- Table: faq
-- Description: holds the individual faq's for a particular
-- project.


create sequence faq_faq_id_seq;
create table faq (
  faq_id       int4 not null default nextval('faq_faq_id_seq'),
  project_id   int4 not null references project(project_id),
  version_id   int4,
  member_id    int4 not null references member(member_id),
  question     text not null,
  response     text not null,
  create_date  date not null default now(),
  modify_date  date not null default now(),
  example_1    text,
  display      bool default 't',
  primary key (faq_id)
);

-- Table: faq_url
-- Description: holds any reference urls the project admin
-- might want attached to a particular faq

create table faq_url (
  faq_id       int4 not null references faq(faq_id),
  url          varchar(500) not null,
  title        varchar(250),
  primary key (faq_id,url,title)
);

-- Table: faq_response
-- Description: holds all responses for each faq that are
-- submitted by users.

create table faq_response (
  user_id      varchar(32) not null unique default now(),
  faq_id       int4 not null references faq(faq_id),
  subject      varchar(150) not null,
  comment      text,
  primary key(user_id)
);

-- table: faq_category
-- description: holds all user-defined faq categories
create sequence faq_cat_id_seq;
create table faq_category (
  cat_id       int4 not null default nextval('faq_cat_id_seq'),
  project_id   int4 not null references project(project_id),
  member_id    int4 not null references member(member_id),
  create_date  date default now(),
  cat_name     varchar(500) not null,
  description  text,
  primary key(cat_id)
);

--table faq_cat_group
-- description: groups all of the different categories a faq can 
-- be in

create table faq_cat_group (
  faq_id       int4 not null references faq(faq_id),
  cat_id       int4 not null references faq_category(cat_id),
  primary key (faq_id,cat_id)
);

