/*
 * File: site_content.sql
 *
 * Description: contains tables for dealing with content (greatbridge.com)
 *
 * Creator: Allen McGrath <amcgrath@greatbridge.com>
 * Created: 10/17/2000
 *
 * Change Log:
 *     Allen McGrath <amcgrath@greatbridge.com> 10/17/2000
 *         - Intial file creation
 *     Chris Ryan <chris@greatbridge.com> 10/25/2000
 *         - Added file and table comments
 */

/*
 * Table: site_content
 *
 * Description:
 *
 * Field Description:
 * content_id     the id of this content record (primary key)
 * temp_id        used to track double clicks and handle them
 *                also used as the file name for storing the body text
 * group_id       the site group id that this record is part of
 * cat_id         the type content this is
 * submit_date    the date this content was added
 * start_date     the date this content shows up on the site
 * end_date       the date this content should stop showing up on the site
 * slug           something like a header/title (it's a writer thing)
 * title          the title of the content
 * subtitle       the subtitle of the content
 * author         the person who wrote this content
 * email          the email address to contact about this article
 * body           not used cause of size limitations we use files instead
 * url            a url to link to for this article
 * home_page      if this article should show up on the home page of a site
 */
create sequence content_content_id_seq;
create table site_content (
    content_id    int4 not null default nextval('content_content_id_seq'),
    temp_id       varchar(32),
    group_id      int4 not null references site_group(group_id) default 0,
    cat_id        int4 not null references category(cat_id),
    submit_date   date default now(),
    start_date    date default now(),
    end_date      date default now() + 180,
    slug          varchar(50),
    title         varchar(250),
    subtitle      varchar(500),
    author        varchar(150),
    email         varchar(100),
    body          text,
    url           varchar(250),
    home_page     bool default 't',
    primary key   (content_id)
);
 
